@@ -17,7 +17,7 @@ from apscheduler.triggers.date import DateTrigger
 from apscheduler.triggers.interval import IntervalTrigger
 from dotenv import load_dotenv
 from mysql.connector import Error as mysqlError
-from pydantic import BaseModel
+from pydantic import BaseModel, constr
 from telegram import Bot
 
 from .mysql_basic import *
@@ -27,6 +27,11 @@ load_dotenv(Path.cwd() / '.env')
 logger = logging.getLogger("rw_scheduler")
 
 
+class ExecutionStatus(Enum):
+    ok = auto()
+    error = auto()
+
+
 class TaskState(Enum):
     new = auto(), '🌱'
     scheduled = auto(), '🪵'
@@ -96,7 +101,8 @@ class Task(BaseModel):
     id: int
     status: TaskState
     comment: Optional[str]
-    target_system: str
+    target_system: constr(max_length=100)
+    ordering_system: Optional[constr(max_length=100)]
     job_info: JobInfo
     return_msg: Optional[str]
     mysql_cnx: Optional[mysql.MySQLConnection]
@@ -133,10 +139,11 @@ class Task(BaseModel):
         )
 
     @classmethod
-    def create(cls, job_info: JobInfo, target_system: str, comment: str = None):
-        query = f"INSERT INTO db_global.ScheduleJob(job_info,target_system,comment) VALUES(%s,%s,%s)"
+    def create(cls, job_info: JobInfo, target_system: str, ordering_system: str, comment: str = None):
+        query = f"INSERT INTO db_global.ScheduleJob(job_info,target_system,ordering_system,comment) VALUES(%s,%s,%s,%s)"
         _, cnx = execute_query(query,
-                               values=(job_info.json(exclude_unset=True, ensure_ascii=False), target_system, comment),
+                               values=(job_info.json(exclude_unset=True, ensure_ascii=False), target_system,
+                                       ordering_system, comment),
                                reuse_cnx=True)
         query = f"SELECT LAST_INSERT_ID()"
         res, _ = select_query(query, cnx=cnx)
@@ -190,8 +197,9 @@ class Task(BaseModel):
                 self.send_bot_info(bot_info, msg)
 
     def execution_info_end(self, result: str = None, duration: timedelta = None):
-        query = f"INSERT INTO db_global.Executions(task_id, result_msg, duration) VALUES (%s,%s,%s)"
-        _ = execute_query(query, (self.id, result, str(duration)))
+        query = f"INSERT INTO db_global.Executions(task_id, result_msg, duration, execution_status) " \
+                f"VALUES (%s,%s,%s,%s)"
+        _ = execute_query(query, (self.id, result, str(duration), ExecutionStatus.ok.value))
         for bot_info in self.job_info.bot_info:
             if bot_info.info_on_success:
                 if bot_info.msg_on_success is None:
@@ -204,9 +212,10 @@ class Task(BaseModel):
                 self.send_bot_info(bot_info, msg)
 
     def execution_info_end_with_error(self, error: BaseException, duration: timedelta = None):
-        query = f"INSERT INTO db_global.Executions(task_id, result_msg, duration) VALUES (%s,%s,%s)"
+        query = f"INSERT INTO db_global.Executions(task_id, result_msg, duration, execution_status) " \
+                f"VALUES (%s,%s,%s,%s)"
         error_msg = f"{type(error).__name__}: {error}"
-        _ = execute_query(query, (self.id, error_msg, str(duration)))
+        _ = execute_query(query, (self.id, error_msg, str(duration), ExecutionStatus.error.value))
         for bot_info in self.job_info.bot_info:
             if bot_info.info_on_exception:
                 if bot_info.msg_on_exception is None:
@@ -235,11 +244,8 @@ class Task(BaseModel):
         if "job" in kwargs:
             self.job = kwargs["job"]
             if self.job is not None:
-                query = f'SELECT nextStart FROM db_global.ScheduleJob WHERE id=%s'
-                res, _ = select_query(query, values=(self.id,))
-                prev_start = res[0]['nextStart'] if res else None
-                query = f'UPDATE db_global.ScheduleJob SET lastStart=%s, nextStart=%s WHERE id=%s'
-                _ = execute_query(query, (prev_start, self.job.next_run_time, self.id))
+                query = f'UPDATE db_global.ScheduleJob SET nextStart=%s WHERE id=%s'
+                _ = execute_query(query, (self.job.next_run_time, self.id))
             else:
                 query = f'UPDATE db_global.ScheduleJob SET nextStart=%s WHERE id=%s'
                 _ = execute_query(query, (None, self.id))
